import json
from aliyunsdkcore.client import AcsClient
from aliyunsdkcore.acs_exception.exceptions import ClientException
from aliyunsdkcore.acs_exception.exceptions import ServerException
from aliyunsdkvod.request.v20170321.GetPlayInfoRequest import GetPlayInfoRequest
from flask import request, jsonify, session, current_app
from sqlalchemy import func, desc, or_
from apps.models import *
from apps.view_attract import api_attract
from apps.utils.response_code import RET
from apps import db, constants, redis_store


# 获取左上角经济指标数据
def get_jjzb(district):
    '''经济指标数据'''
    # years = [2021]  # 指定数据的年份，与数据库中数据对齐
    try:
        if not district or district == '晋城市':
            datas = City.query.filter_by(area='晋城市').first()
        else:
            datas = City.query.filter_by(area=district).first()
        df_dic = {"GDP": '%.2f亿元' % (datas.GDP / 10000) if datas.GDP else "-亿元",  # 地区生产总值
                  "addscale": '%.2f' % datas.addscale + "%" if datas.addscale else "-%",  # 规上工业增加值增速
                  "investment": '%.2f亿元' % (datas.investment / 10000) if datas.investment else "-亿元",  # 固定资产投资
                  "retail": '%.2f亿元' % (datas.retail / 10000) if datas.retail else "-亿元",  # 社会消费品零售额
                  "in_out": '%.2f亿元' % (datas.in_out / 10000) if datas.in_out else "-亿元",  # 进出口总额
                  "public": '%.2f亿元' % (datas.public / 10000) if datas.public else "-亿元",  # 一般公共预算支出
                  "people_out": '%.2f元' % datas.people_out if datas.people_out else "-元",  # 居民人均可支配收入
                  "people_per": '%.2f' % datas.people_per if datas.people_per else "-"}  # 居民消费价格指数
        # print(df_dic)
        # return jsonify(code=RET.OK, msg="查找成功", data=df)
        return df_dic
        # return df
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="数据库错误")



@api_attract.route("/index", methods=["GET"])
def index():
    return '德旭，你好！'


# 左上角企业数量各资质统计、左上角获取经济指标数据、产业机构分布饼状图数据统计
@api_attract.route("/menu", methods=["POST"])
def menu():
    '''左上角企业数量各资质统计、左上角获取经济指标数据、产业机构分布饼状图数据统计'''
    req_dict = request.get_json()
    district = req_dict.get("district")  # 区县或者开发区名称

    # 区县名称转换字典
    district_dict = {
        '沁水县': '沁水县',
        '高平市': '高平市',
        '陵川县': '陵川县',
        '阳城县': '阳城县',
        '泽州县': '泽州县',
        '城区': '城区'
    }

    if not district or district == '晋城市':
        try:
            company = Company.query.filter_by(city="晋城市")
        except Exception as e:
            current_app.logger.error(e)
            return jsonify(code=RET.DBERR, msg="数据库错误")
    else:
        try:
            # company = Company.query.filter(Company.induzone == district_dict[district], Company.city == "晋城市")
            company = Company.query.filter(Company.district == district_dict[district], Company.city == "晋城市")
        except Exception as e:
            current_app.logger.error(e)
            return jsonify(code=RET.DBERR, msg="数据库错误")

    # 1. 左上角企业数量各资质统计
    try:
        # 晋城市
        t_c5 = company.filter_by(isfive="1").count()  # 500强
        ssqy = company.filter_by(quoted_company="1").count()  # 上市
        if district != "晋城市":
            gmys = Company.query.filter(Company.induzone == district_dict[district]).filter_by(
                scale="1").count()  # 规模(2-5) 622
        else:
            gmys = Company.query.filter_by(scale="1").count()
        zjtx = company.filter_by(zjtg="1").count()  # 专精特新
        gxjs = company.filter_by(high_new="1").count()  # 高新
        kjzx = company.filter_by(tbe="1").count()  # 科技型中小企业
        dengl = company.filter_by(dengl="1").count()  # 瞪羚
        dujs = company.filter_by(unicorn="1").count()  # 独角兽

        table_dic = {"t_c5": t_c5,  # 500强企业
                     "ssqy": ssqy,  # 上市企业
                     "gmys": gmys,  # 规模以上企业
                     "zjtx": zjtx,  # 专精特新企业
                     "gxjs": gxjs,  # 高新技术企业
                     "kjzx": kjzx,  # 科技型中小企业
                     "dengl": dengl,  # 瞪羚企业
                     "dujs": dujs}  # 独角兽企业

        # 2. 左上角获取经济指标数据
        jjzb_data = get_jjzb(district)
        # 3. 产业机构分布饼状图数据统计
        count_all = company.count()
        if count_all == 0:
            count_all = 1
        count_mcq = company.filter_by(f_type=1).count()  # 煤层气
        count_gjd = company.filter_by(f_type=3).count()  # 光机电
        count_mtmhg = company.filter_by(f_type=4).count()  # 煤炭煤化工
        count_gtzz = company.filter_by(f_type=2).count()  # 钢铁铸造
        count_qyly = company.filter_by(f_type=5).count()  # 全域旅游和康养
        # count_xdfu = company.filter_by(f_type=6).count()  # 现代服务业
        # count_qt = count_all - count_mcq - count_gjd - count_mtmhg - count_gtzz - count_qyly - count_xdfu
        count_qt = count_all - count_mcq - count_gjd - count_mtmhg - count_gtzz - count_qyly
        mcq = int(count_mcq / count_all * 100)
        gjd = int(count_gjd / count_all * 100)
        mtmhg = int(count_mtmhg / count_all * 100)
        gtzz = int(count_gtzz / count_all * 100)
        qyly = int(count_qyly / count_all * 100)
        # xdfu = int(count_xdfu / count_all * 100)
        # qt = 100 - mcq - gjd - mtmhg - gtzz - qyly - xdfu
        qt = 100 - mcq - gjd - mtmhg - gtzz - qyly
        # 产业结构分布
        industry = [
            {"per": mtmhg, "name": "煤炭煤化工", "count": count_mtmhg},
            {"per": mcq, "name": "煤层气", "count": count_mcq},  # {百分比，value}
            {"per": gjd, "name": "光机电", "count": count_gjd},
            {"per": gtzz, "name": "钢铁铸造", "count": count_gtzz},
            {"per": qyly, "name": "全域旅游和康养", "count": count_qyly},
            {"per": qt, "name": "其他", "count": count_qt},
        ]

        # TODO 4.五大千亿级产业集群

        data = {
            "jjzb_dic": jjzb_data,  # 左上角经济指标数据
            "table_dic": table_dic,  # 左上角企业数据统计
            "industry_dic": industry  # 产业结构分布饼状图数据
        }

        return jsonify(code=RET.OK, msg="查找成功", data=data)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="数据库错误")


# 招商引资作战图、项目数量/金额分布图
@api_attract.route("/project", methods=["POST"])
def project():
    req_dict = request.get_json()
    district = req_dict.get("district")  # 区县或者开发区名称
    try:
        project_map = []
        industry_money = []
        industry_nums = []
        list1 = ["晋城市", "沁水县", "高平市", "陵川县", "阳城县", "泽州县", "城区"]

        # 晋城市，点击区县之前默认数据
        if not district or district == '晋城市':
            for i in list1:
                # 1.招商引资作战图数据
                ss = Examine.query.filter_by(district=i).first()
                project_map.append({"name": i,
                                    "nums1": "{}亿元".format(ss.sign_finnish),
                                    "add1": ss.sign_grade,
                                    "nums2": "{}亿元".format(ss.start_finish),
                                    "add2": ss.start_grade,
                                    "nums3": "{}亿元".format(ss.invest_finish),
                                    "add3": ss.invest_grade
                                    })
            # 产业数量/金额分布图数据
            # types_list = []
            # industry_dic = {}
            project_list = NewProject.query.filter_by(district="晋城市").all()
            i = 0
            for project in project_list:
                i += 1
                if i > 6:
                    pass
                else:
                    industry_money.append({"name": project.type,
                                           "value": project.money})
                    industry_nums.append({"name": project.type,
                                          "value": project.number})
                    # money_list = []
                    #
                    # types = project.type
                    # money = project.money
                    # if types in types_list:
                    #     industry_dic[types].append(money)
                    # money_list.append(money)
                    # industry_dic.update({types:money_list})
                    # types_list.append(types)

        # 点击区县后的联动数据
        else:
            # 1.招商引资作战图数据
            ss = Examine.query.filter_by(district=district).first()
            project_map.append({"name": district,
                                "nums1": "{}亿元".format(ss.sign_finnish),
                                "add1": ss.sign_grade,
                                "nums2": "{}亿元".format(ss.start_finish),
                                "add2": ss.start_grade,
                                "nums3": "{}亿元".format(ss.invest_finish),
                                "add3": ss.invest_grade
                                })
            # 产业数量/金额分布图数据
            i = 0
            project_list = NewProject.query.filter_by(district=district).all()
            for project in project_list:
                i += 1
                if i > 6:
                    pass
                else:
                    industry_money.append({"name": project.type,
                                           "value": project.money})
                    industry_nums.append({"name": project.type,
                                          "value": project.number})
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="数据库错误")

    data = {
        "project_map": project_map,  # 招商引资作战图
        "industry_nums": industry_nums,  # 已签约项目数量产业分布图
        "industry_money": industry_money,  # 已签约项目投资金额产业分布图
    }
    return jsonify(code=RET.OK, msg="获取成功", data=data)


# 政策和重点项目
@api_attract.route("/propol", methods=["POST"])
def propol():
    req_dict = request.get_json()
    district = req_dict.get("district")  # 县区

    try:
        if not district or district == "晋城市":
            # name_query = "project-propol"
            # if redis_store.get(name_query) is not None:
            #     data = json.loads(redis_store.get(name_query))
            #     return jsonify(code=RET.OK, msg="获取成功", data=data)
            project = Project.query.all()
            policy = InduPolicy.query.filter_by(district="晋城市").order_by(InduPolicy.pubdate.desc())
            data_policy = [{"name": i.name, "id": i.id, "distict": "太原市"} for i in policy.all()]
            data_project = [{"name": i.name, "id": i.id} for i in project]
            data = {
                "project": data_project,
                "policy": data_policy,
            }
            # redis缓存
            # redis_store.set(name_query, json.dumps(data))
            # redis_store.expire(name_query, 1 * 24 * 3600)
        else:  # 区县、开发区
            project = Project.query.filter_by(district=district)
            policy = InduPolicy.query.filter_by(district=district).order_by(InduPolicy.pubdate.desc())
            data_policy = [{"name": i.name, "id": i.id, "distict": district} for i in policy.all()]
            data_project = [{"name": i.name, "id": i.id} for i in project.all()]
            data = {
                "project": data_project,  # 重点项目
                "policy": data_policy,  # 政策

            }

        return jsonify(code=RET.OK, msg="查询成功", data=data)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DATAERR, msg="数据库错误")


# 获取区县的详情
@api_attract.route("/getInfo", methods=["POST"])
def get_info():
    req_dic = request.get_json()
    district = req_dic.get("district")  # 地区

    if not district:
        return jsonify(code=RET.PARAMERR, msg="参数不完整")

    try:
        city = City.query.filter_by(area=district).first()
        info = city.info
        detail_dic = {
            "detail_data": info
        }
        return jsonify(code=RET.OK, msg="查询成功", data=detail_dic)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="数据库错误")


# 获取区县视频url
@api_attract.route("/video", methods=["POST"])
def attract_video():
    req_dic = request.get_json()
    district = req_dic.get("district")

    if not district:
        return jsonify(code=RET.PARAMERR, msg="参数不全")

    # district_dict = {'晋城市': '晋城市',
    #                  '沁水市': '沁水市',
    #                  '高平市': '高平市',
    #                  '陵川市': '陵川市',
    #                  '阳城市': '阳城市',
    #                  '泽州市': '泽州市',
    #                  '城区': '城区'
    #                  }
    try:
        video = Video.query.filter_by(district=district).first()
    except Exception as e:
        current_app.logger.error(e)
    if video:
        url = video.video_id1
        if url:
            return jsonify(code=RET.OK, msg="查询成功", data={"url": url})
    else:
        return jsonify(code=RET.DATAERR, msg="区县名称有误，没有相关视频")

    return jsonify(code=RET.NODATA, msg="暂无视频", data={"url": ""})


# 获取重点项目的详情，详情页
@api_attract.route("/keyProject", methods=["POST"])
def keyproject():
    req_dic = request.get_json()
    id = req_dic.get("id")
    if not id:
        return jsonify(code=RET.PARAMERR, msg="参数不完整")

    try:
        project = Project.query.get(id)
        data = {
            "name": project.name,  # 工程名
            "district": project.district,  # 区县名称
            "type": project.type,  # 工程类型
            "money": project.money,  # 项目投资金额
            "background": project.background,  # 项目背景
            "content": project.content,  # 项目的具体内容
            "way": project.way,  # 拟引资方式及内容
            "company": project.company,  # 招商单位
            "contact": project.contact,  # 联系方式
            "email": project.email  # 电子邮箱
        }
        return jsonify(code=RET.OK, msg="查找成功", data=data)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="数据库错误")


# 政策详情
@api_attract.route("/policyDetails", methods=["POST"])
def policy_details():
    req_dic = request.get_json()
    _id = req_dic.get("id")
    if not _id:
        return jsonify(code=RET.PARAMERR, msg="参数不全")
    try:
        _id1 = int(_id) + 1
        _id2 = int(_id) - 1
        if _id2 < 1:
            _id2 = ''
        policy = InduPolicy.query.get(_id)
        policy1 = InduPolicy.query.get(str(_id1))
        policy2 = InduPolicy.query.get(str(_id2))
        data = {"name": policy.name,  # 政策名
                "file": policy.file if policy.file else "-",  # 本地文件位置
                "category": policy.category if policy.category else "-",  # 政策类型
                "org": policy.org if policy.org else "-",  # 政策发布机构
                "industry": policy.industry if policy.industry else "-",  # 行业名称
                "district": policy.district if policy.district else "-",  # 政策发布地区
                "pubdate": str(policy.pubdate)[0:10] if policy.pubdate else "-",  # 发布时间
                "url": policy.url if policy.pubdate else "-",  # 外链接
                "post_num": policy.post_num if policy.post_num else "",  # 发文字号
                "last": [policy2.name, _id1] if policy2 else "",
                "next": [policy1.name, _id2] if policy1 else ""}
        return jsonify(code=RET.OK, msg="查找成功", data=data)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="数据库错误")


# 列表展示左上角企业
@api_attract.route("/showListb", methods=["POST"])
def showListb():
    req_dic = request.get_json()
    type = req_dic.get("type")  # 12345678 （500强-上市-规模-专精特新-高新-科技中小-瞪羚-独角兽）
    district = req_dic.get("district")
    page = req_dic.get("page")

    if not all([type, district]):
        return jsonify(code=RET.PARAMERR, msg="参数错误")

    if not page:
        page = 1
    try:
        # 企业
        if district == "晋城市":
            company = Company.query.filter_by(city="晋城市")
        else:
            company = Company.query.filter_by(city="晋城市", district=district)
        size = company.count()
        if type == 1:
            company = company.filter_by(isfive=1)
            size = company.count()
        if type == 2:
            company = company.filter_by(quoted_company=1)
            size = company.count()
        if type == 3:
            if district == "晋城市":
                company = Company.query.filter_by(scale="1")
            else:
                company = Company.query.filter_by(district=district, scale="1")
            size = company.count()
        if type == 4:
            company = company.filter_by(zjtg=1)
            size = company.count()
        if type == 5:
            company = company.filter_by(high_new=1)
            size = company.count()
        if type == 6:
            company = company.filter_by(tbe=1)
            size = company.count()
        if type == 7:
            company = company.filter_by(dengl=1)
            size = company.count()
        if type == 8:
            company = company.filter_by(unicorn=1)
            size = company.count()
        company = company.paginate(page, per_page=4).items
        data = [{
            "id": i.id,
            "name": i.company_name,
            "industry": i.company_industry if i.company_industry else "-",
            "product": i.product if i.product else "-",
            "build_date": "-",
            "capital": i.capital if i.capital else "-",
            "isfive": "500强企业" if i.isfive == "1" else "",
            "quoted_company": i.public_sector if i.public_sector != "空" else "",
            "scale": "规模以上企业" if i.scale == "1" else "",
            "zjtg": "专精特新企业" if i.zjtg == "1" else "",
            "high_new": "高新技术企业" if i.high_new == "1" else "",
            "tbe": "科技型中小企业" if i.tbe == "1" else "",
            "dengl": "瞪羚企业" if i.dengl == "1" else "",
            "unicorn": "独角兽企业" if i.unicorn == "1" else "",
        } for i in company]
        data = {"data_list": data, "size": size}
        return jsonify(code=RET.OK, msg="查找成功", data=data)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="数据库错误")


# 企业信息详情(招商驾驶舱左上角各类企业详情)
@api_attract.route('/companyDetail', methods=['POST'])
def enterprise_detail():
    '''
    企业信息详情
    :return:
    '''

    req_dict = request.get_json()
    _id = req_dict.get("id")  # 企业id

    # 校验参数完整性
    if not all([_id]):
        return jsonify(code=RET.PARAMERR, msg="参数不完整")

    try:
        company = Company.query.get(_id)
        if company:
            data = {"id": company.id,
                    "company_name": company.company_name,  # 企业名
                    "telephone": company.telephone if company.telephone else "-",  # 电话
                    "web_site": company.web_site if company.web_site else "-",  # 网址
                    "email": company.email if company.email else "-",  # 邮箱
                    "address": company.address if company.address else "-",  # 地址
                    "jwd": {"lng": company.lng if company.lng else "-",  # 经度
                            "lat": company.lat if company.lat else "-"},  # 维度
                    "company_info": company.company_info if company.company_info else "-",  # 企业信息
                    "business_scope": company.business_scope if company.business_scope else "-",  # 经营范围
                    "high_new": "高新技术企业" if company.high_new else "-",  # 高新技术企业
                    "legal": company.legal if company.legal else "-",  # 法定代表人
                    "status": company.status if company.status else "-",  # 状态
                    "build_date": str(company.build_date)[:10] if company.build_date else "-",  # 创建时间
                    "capital": company.capital if company.capital else "-",  # 注册资本
                    "social_code": company.social_code if company.social_code else "-",  # 统一社会信用代码
                    # "taking": company.takingn if company.takingn else "-",  # 营收 (万元)
                    "bao": company.bao_num if company.bao_num else "-",  #参保人数
                    "entype": company.entype if company.entype else "-",  # 企业类型
                    "industry": company.company_industry if company.company_industry else "-",  # 所属行业
                    "scope": company.business_scope if company.business_scope else "-",  # 企业经营范围
                    # "collect": "1",
                    # "choice": "3"
                    "tax_code": company.tax_code if company.tax_code else "-",
                    "register_code": company.register_code if company.register_code else "-",
                    }
        else:
            return jsonify(code=RET.NODATA, msg="查无数据")
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="数据库查询错误")
    return jsonify(code=RET.OK, msg="获取成功", data=data)


# 删除缓存
@api_attract.route("/deleteX", methods=["GET"])
def deleteX():
    redis_store.delete("project-propol")
    return jsonify(code=RET.OK, msg="删除成功")


# 删除缓存
@api_attract.route("/vis", methods=["GET"])
def vis():
    redis_store.delete("project-propol")
    return jsonify(code=RET.OK, msg={"remote_addr": request.remote_addr,
                                     "X-Real-Ip": request.headers.get("X-Real-Ip"),
                                     "X-Forwarded-For": request.headers.get("X-Forwarded-For"),
                                     "HOST": request.headers.get("Host"),
                                     "X-Forwarded-Proto": request.headers.get("X-Forwarded-Proto"),
                                     })
